==> mobile_pos-0.8.18.tar.gz: lib/src/views/card_payment/insert_card.dart <==
// ignore_for_file: use_build_context_synchronously

import 'dart:async';

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/mobile_pos_platform_interface.dart';
import 'package:mobile_pos/mobile_pos_sdk.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/helpers/logger.dart';
import 'package:mobile_pos/src/models/raven_const.dart';
import 'package:mobile_pos/src/network/api_requests.dart';
import 'package:mobile_pos/src/shared_widgets/raven_money_text.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/views/card_payment/card_pin.dart';

class InsertCard extends StatefulWidget {
  final double amount;
  final String deviceName;
  final PaymentType paymentType;
  const InsertCard(
      {super.key,
      required this.amount,
      required this.deviceName,
      required this.paymentType});

  @override
  State<InsertCard> createState() => _InsertCardState();
}

class _InsertCardState extends State<InsertCard> {
  StreamSubscription? streamSubscription;
  @override
  void initState() {
    streamSubscription = MobilePosPlatform
        .instance.channelStreamController!.stream
        .listen((event) async {
      if (event.eventType == RavenMPosEventType.pin) {
        if (mounted) {
          replaceRoute(
              context,
              CardPin(
                paymentType: widget.paymentType,
                deviceName: widget.deviceName,
                amount: widget.amount,
              ));
          streamSubscription!.cancel();
        }
      }
      if (event.eventType == RavenMPosEventType.transactionError) {
        streamSubscription!.cancel();
        MobilePosPlatform.instance.disconnectDevice();

        if (mounted) {
          Navigator.pop(context);
          showSnack(context, "${event.data}... please try again");
        }
      }
      if (event.eventType == RavenMPosEventType.disconnected) {
        if (mounted) {
          Navigator.pop(context);
          showSnack(context, "device disconnected... please try again");
        }

        return;
      }
      if (event.eventType == RavenMPosEventType.processPayment) {
        if (mounted) {
          setAppState();
          streamSubscription!.cancel();
          MobilePosPlatform.instance.disconnectDevice();
          if (event.data != null) {
            logData(event.data);
            if (widget.paymentType == PaymentType.card) {
              await ApiRequests.processCard(
                  context, widget.amount, event.data ?? '');
            }
            if (widget.paymentType == PaymentType.checkBalance) {
              await ApiRequests.getCardBalance(context, event.data ?? '');
            }
          } else {
            pluginConfig.onError.call(
                BankBoxException(code: kNibbsError, message: 'Payment failed'));
          }
        }
      }
    });
    super.initState();
  }

  int currentIndex = 0;
  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return WillPopScope(
      onWillPop: () async {
        MobilePosPlatform.instance.disconnectDevice();
        return true;
      },
      child: RavenPayScaffold(
        showLogo: true,
        body: Column(
          children: [
            const Gap(24),
            Padding(
              padding:
                  EdgeInsets.symmetric(horizontal: kHoriontalScreenPadding),
              child: Row(
                children: [
                  RavenPayCloseButton(
                    isArrow: true,
                    text: "",
                    onBackPressed: () {
                      MobilePosPlatform.instance.disconnectDevice();
                      Navigator.pop(context);
                    },
                  ),
                ],
              ),
            ),
            const Gap(12),
            Container(
                padding: const EdgeInsets.symmetric(horizontal: 20),
                height: 60,
                width: double.infinity,
                decoration: BoxDecoration(
                    border: Border.all(
                        color: const Color(0xffDADADA).withOpacity(0.31))),
                child: Row(
                  children: [
                    Expanded(
                      child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: [
                            Text("Payment To",
                                overflow: TextOverflow.ellipsis,
                                style: subtitle2),
                            const Gap(6),
                            Text(widget.deviceName,
                                style: headling1.copyWith(fontSize: 14))
                          ]),
                    ),
                    const Gap(34),
                    if (widget.paymentType == PaymentType.card) ...[
                      Container(
                        padding: const EdgeInsets.symmetric(
                            horizontal: 12, vertical: 8),
                        decoration: BoxDecoration(
                            color: AppColors.lightOragen,
                            borderRadius: BorderRadius.circular(24)),
                        child: RavenPayMoneyWidget(
                          amount: widget.amount.toString(),
                          color: AppColors.ravenOrageColor,
                        ),
                      )
                    ]
                  ],
                )),
            const Gap(24),
            Expanded(
              child: Column(children: [
                Image.asset(
                  loadAsset("insert_card.gif"),
                  width: double.infinity,
                ),
                const Gap(12),
                Text(
                  "Insert Card",
                  style: headling2.copyWith(fontSize: 20),
                ),
                // const Gap(12),
                // Padding(
                //   padding: const EdgeInsets.symmetric(horizontal: 24),
                //   child: Text(
                //     "Insert your card into the terminal device, and wait while we read card information.",
                //     style: subtitle2.copyWith(fontSize: 14),
                //     textAlign: TextAlign.center,
                //   ),
                // ),
              ]),
            ),
            Text("SUPPORTED BY", style: subtitle2.copyWith()),
            const Gap(8),
            Padding(
              padding: EdgeInsets.symmetric(horizontal: size.width * 0.1),
              child: Image.asset(loadAsset("supported_card.png")),
            ),
            if (pluginConfig.showLabel) ...[
              const Gap(64),
            ]
          ],
        ),
      ),
    );
  }

  void setAppState() {
    if (mounted) {
      setState(() {});
    }
  }
}

==> mobile_pos-1.1.1.tar.gz: lib/src/views/card_payment/insert_card.dart <==
// ignore_for_file: use_build_context_synchronously

import 'dart:async';
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/mobile_pos_platform_interface.dart';
import 'package:mobile_pos/mobile_pos_sdk.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/helpers/logger.dart';
import 'package:mobile_pos/src/models/raven_const.dart';
import 'package:mobile_pos/src/network/api_requests.dart';
import 'package:mobile_pos/src/shared_widgets/progress_dialog.dart';
import 'package:mobile_pos/src/shared_widgets/raven_money_text.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/views/card_payment/card_pin.dart';

class InsertCard extends StatefulWidget {
  final double amount;
  final String deviceName;
  final PaymentType paymentType;
  const InsertCard(
      {super.key,
      required this.amount,
      required this.deviceName,
      required this.paymentType});

  @override
  State<InsertCard> createState() => _InsertCardState();
}

class _InsertCardState extends State<InsertCard> {
  StreamSubscription? streamSubscription;
  @override
  void initState() {
    streamSubscription = MobilePosPlatform
        .instance.channelStreamController!.stream
        .listen((event) async {
      if (event.eventType == RavenMPosEventType.pin) {
        if (mounted) {
          replaceRoute(
              context,
              CardPin(
                paymentType: widget.paymentType,
                deviceName: widget.deviceName,
                amount: widget.amount,
              ));
          streamSubscription!.cancel();
        }
      }
      if (event.eventType == RavenMPosEventType.transactionError) {
        streamSubscription!.cancel();
        if (mounted) {
          Navigator.pop(context);
          showSnack(context, "${event.data}... please try again");
        }
      }
      if (event.eventType == RavenMPosEventType.disconnected) {
        if (mounted) {
          Navigator.pop(context);
          showSnack(context, "device disconnected... please try again");
        }

        return;
      }
      if (event.eventType == RavenMPosEventType.onNFCPaymentInitiated) {
        if (mounted) {
          showDialog(
              barrierDismissible: false,
              context: context,
              builder: (BuildContext context) => const ProgressDialog(
                    status: 'Processing...',
                  ));
        }

        return;
      }
      if (event.eventType == RavenMPosEventType.processPayment) {
        if (mounted) {
          Navigator.pop(context);
          setAppState();
          streamSubscription!.cancel();
          if (event.data != null) {
            logData(event.data);
            if (widget.paymentType == PaymentType.card) {
              await ApiRequests.processCard(
                  context, widget.amount, event.data ?? '');
            }
            if (widget.paymentType == PaymentType.checkBalance) {
              await ApiRequests.getCardBalance(context, event.data ?? '');
            }
          } else {
            pluginConfig.onError.call(
                BankBoxException(code: kNibbsError, message: 'Payment failed'));
          }
        }
      }
    });
    super.initState();
  }

  int currentIndex = 0;
  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return PopScope(
      canPop: false,
      child: RavenPayScaffold(
        showLogo: true,
        body: Column(
          children: [
            const Gap(24),
            Padding(
              padding:
                  EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
              child: Row(
                children: [
                  RavenPayCloseButton(
                    isArrow: true,
                    text: "",
                    onBackPressed: () {
                      Navigator.pop(context);
                    },
                  ),
                ],
              ),
            ),
            const Gap(12),
            Container(
                padding: const EdgeInsets.symmetric(horizontal: 20),
                height: 60,
                width: double.infinity,
                decoration: BoxDecoration(
                    border: Border.all(
                        color: const Color(0xffDADADA).withOpacity(
                            pluginTheme.isLightTheme ? 0.31 : 0.08))),
                child: Row(
                  children: [
                    Expanded(
                      child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: [
                            Text("Payment To",
                                overflow: TextOverflow.ellipsis,
                                style: subtitle2),
                            const Gap(6),
                            Text(widget.deviceName,
                                style: headling1.copyWith(fontSize: 14))
                          ]),
                    ),
                    const Gap(34),
                    if (widget.paymentType == PaymentType.card) ...[
                      Container(
                        padding: const EdgeInsets.symmetric(
                            horizontal: 12, vertical: 8),
                        decoration: pluginTheme.isLightTheme
                            ? BoxDecoration(
                                color: AppColors.lightOrange,
                                borderRadius: BorderRadius.circular(24))
                            : null,
                        child: RavenPayMoneyWidget(
                          amount: widget.amount.toString(),
                          color: AppColors.ravenOrangeColor,
                        ),
                      )
                    ]
                  ],
                )),
            Gap(size.height * 0.02),
            Expanded(
              child: Column(children: [
                Gap(size.height * 0.04),
                Container(
                  margin: const EdgeInsets.symmetric(horizontal: 24),
                  decoration: BoxDecoration(
                      color: pluginTheme.isLightTheme
                          ? AppColors.borderGrey.withOpacity(0.5)
                          : pluginTheme.getFGColor.withOpacity(0.5),
                      borderRadius: BorderRadius.circular(28),
                      border: Border.all(
                          color: pluginTheme.isLightTheme
                              ? AppColors.borderGrey
                              : pluginTheme.getFGColor,
                          width: 2)),
                  child: Column(
                    children: [
                      const Gap(12),
                      Text(
                        widget.paymentType == PaymentType.card
                            ? ((bluetoothModel?.tapStatus ?? 0) == 1
                                ? "Insert Card/Tap Card"
                                : "Insert Card")
                            : "Insert Card",
                        style: headling2.copyWith(fontSize: 18),
                      ),
                      Container(
                        height: size.height * 0.35,
                        padding: const EdgeInsets.all(16),
                        margin: const EdgeInsets.only(top: 8),
                        decoration: BoxDecoration(
                            color: pluginTheme.isLightTheme
                                ? Colors.white
                                : AppColors.ravenPayDark,
                            borderRadius: BorderRadius.circular(24),
                            border: Border.all(
                                color: pluginTheme.isLightTheme
                                    ? AppColors.borderGrey
                                    : pluginTheme.getFGColor,
                                width: 2)),
                        child: Image.asset(
                          loadAsset("insert_card.gif"),
                          width: double.infinity,
                        ),
                      ),
                    ],
                  ),
                ),
                Gap(size.height * 0.04),
                Container(
                  margin: EdgeInsets.symmetric(
                      horizontal: kHorizontalScreenPadding),
                  child: Text(
                    "Insert your card into the terminal device, and wait while we read card information.",
                    style: subtitle.copyWith(fontWeight: FontWeight.w400),
                    textAlign: TextAlign.center,
                  ),
                ),
              ]),
            ),
            Text("SUPPORTED BY", style: subtitle2.copyWith()),
            const Gap(8),
            Padding(
              padding: EdgeInsets.symmetric(horizontal: size.width * 0.1),
              child: Image.asset(loadAsset("supported_card.png")),
            ),
            if (pluginConfig.showLabel) ...[
              const Gap(64),
            ]
          ],
        ),
      ),
    );
  }

  void setAppState() {
    if (mounted) {
      setState(() {});
    }
  }
}
